(function (factory) {
    if (typeof module === "object" && typeof module.exports === "object") {
        var v = factory(require, exports);
        if (v !== undefined) module.exports = v;
    }
    else if (typeof define === "function" && define.amd) {
        define(["require", "exports"], factory);
    }
})(function (require, exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    function toHTML(src) {
        var html = "";
        function escape(text) {
            return new Option(text).innerHTML;
        }
        function inlineEscape(str) {
            return str.replace(/!\[([^\]]*)]\(([^(]+)\)/g, '<img alt="$1" src="$2" />')
                .replace(/\[([^\]]+)]\(([^(]+)\)/g, '$1'.link('$2'))
                .replace(/`([^`]+)`/g, function (match, p1, offset, string) {
                return "<code>" + escape(p1) + "</code>";
            })
                .replace(/\*\*([^*]+)\*\*/g, '<strong>$1</strong>')
                .replace(/\*([^*]+)\*/g, '<em>$1</em>')
                .replace(/  \n/g, '<br />');
        }
        function processWrappedMarkdown(prependType, line) {
            return prependType[1] + ("\n" + line)
                .split(prependType[0])
                .slice(1)
                .map(prependType[3] ? escape : inlineEscape)
                .join(prependType[3] || "</li>\n<li>") + prependType[2];
        }
        function processSemanticMarkdown(char, line) {
            return (char == "#")
                ? ("<h" + (char = line.indexOf(" ")) + ">" + inlineEscape(line.slice(char + 1)) + "</h" + char + ">")
                : (char == "<" ? line : "<p>" + inlineEscape(line) + "</p>");
        }
        src.replace(/&gt;/g, ">").replace(/^\s+|\r|\s+$/g, "").replace(/\t/g, "    ").split(/\n\n+/).forEach(function (line, idx, lines) {
            var char = line[0];
            var prependType = {
                '*': [/\n\* /, "<ul><li>", "</li></ul>"],
                '1': [/\n[1-9]\d*\.? /, "<ol><li>", "</li></ol>"],
                ' ': [/\n    /, "<pre><code>", "</pre></code>", "\n"],
                '>': [/\n> /, "<blockquote>", "</blockquote>", "\n"],
            }[char];
            html += prependType ? processWrappedMarkdown(prependType, line) : processSemanticMarkdown(char, line);
        });
        return html;
    }
    exports.toHTML = toHTML;
});
//# sourceMappingURL=markdown.js.map